==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QStandardItem_shell.h <==
#ifndef QSTANDARDITEM_SHELL_H
#define QSTANDARDITEM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(standarditemmodel)
#include <QtGui/qstandarditemmodel.h>
#endif //QT_CONFIG(standarditemmodel)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qdatastream.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qsize.h>
#include <QtGui/qbrush.h>
#include <QtGui/qfont.h>
#include <QtGui/qicon.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(standarditemmodel)

class QStandardItem_shell : public QStandardItem, public QtJambiShellInterface
{
public:
    QStandardItem_shell();
    QStandardItem_shell(const QIcon& icon0, const QString& text1);
    QStandardItem_shell(const QStandardItem& other0);
    QStandardItem_shell(const QString& text0);
    QStandardItem_shell(int rows0, int columns1 = 1);
    ~QStandardItem_shell() override;

    QStandardItem* clone() const override;
    QVariant data(int role0) const override;
    bool operator<(const QStandardItem& other0) const override;
    void read(QDataStream& in0) override;
    void setData(const QVariant& value0, int role1) override;
    int type() const override;
    void write(QDataStream& out0) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QStandardItem_access : public QStandardItem
{
    void __qt_emitDataChanged(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_assign_cref_QStandardItem(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_data_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint role0) const;
    jboolean __qt_operator_less_cref_QStandardItem_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0) const;
    void __qt_read_ref_QDataStream(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID in0);
    void __qt_setData_cref_QVariant_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject value0, jint role1);
    jint __qt_type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_write_ref_QDataStream_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID out0) const;
};

#endif // QT_CONFIG(standarditemmodel)
#endif // QSTANDARDITEM_SHELL_H

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QStandardItem_shell.h <==
#ifndef QSTANDARDITEM_SHELL_H
#define QSTANDARDITEM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(standarditemmodel)
#include <QtGui/qstandarditemmodel.h>
#endif //QT_CONFIG(standarditemmodel)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qdatastream.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qsize.h>
#include <QtGui/qbrush.h>
#include <QtGui/qfont.h>
#include <QtGui/qicon.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(standarditemmodel)

class QStandardItem_shell : public QStandardItem, public QtJambiShellInterface
{
public:
    QStandardItem_shell();
    QStandardItem_shell(const QIcon& icon0, const QString& text1);
    QStandardItem_shell(const QStandardItem& other0);
    QStandardItem_shell(const QString& text0);
    QStandardItem_shell(int rows0, int columns1 = 1);
    ~QStandardItem_shell() override;

    QStandardItem* clone() const override;
    QVariant data(int role0) const override;
    bool operator<(const QStandardItem& other0) const override;
    void read(QDataStream& in0) override;
    void setData(const QVariant& value0, int role1) override;
    int type() const override;
    void write(QDataStream& out0) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QStandardItem_access : public QStandardItem
{
    void __qt_emitDataChanged(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_assign_cref_QStandardItem(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_data_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint role0) const;
    jboolean __qt_operator_less_cref_QStandardItem_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0) const;
    void __qt_read_ref_QDataStream(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID in0);
    void __qt_setData_cref_QVariant_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject value0, jint role1);
    jint __qt_type_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_write_ref_QDataStream_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID out0) const;
};

#endif // QT_CONFIG(standarditemmodel)
#endif // QSTANDARDITEM_SHELL_H
